# Summary

`aiostorage` is a Python library for performing common object storage 
operations asynchronously.

It currently supports the following object storage providers:

- add providers here

# Installation

`aiostorage` is available on PyPI and can be installed in the usual way.

# Contributing

Follow these [open source contribution guidelines.](https://guyrking.com/2018/03/18/open-source-python-with-github-and-conda.html)

# Documentation

- Add read thedocs link here
- Add wiki link here
